@@ -1,5 +1,7 @@
+use serde::{Deserialize, Serialize};
+
 /*
-n order to get an exported trail to show up in TacO, it needs to be added to a marker pack just like a marker.
+In order to get an exported trail to show up in TacO, it needs to be added to a marker pack just like a marker.
 Trails are described by the <Trail> tag and uses the same category system as the markers.
 If you put a marker and a trail in the same category, the user can hide them both at the same time by hiding the category.
 Here's an example trail:
@@ -16,15 +18,20 @@ The texture tag points to the texture that should scroll on the trail.
 The animSpeed tag is a float value that modifies the speed of the animation on a trail.
 There's also a trailScale tag that is a float value that modifies how stretched the texture will look on the trail.
 */
+
+#[derive(Debug, Clone, Serialize, Deserialize)]
+#[serde(rename_all = "camelCase")]
 pub struct Trail {
-    guid: Option<String>,
-    trail_data: Option<String>,
-    texture: Option<String>,
-    anim_speed: Option<f32>,
-    trail_scale: Option<f32>,
-    color: Option<u32>,
-    //r#type: Option<Category>,
-    alpha: Option<f32>,
-    fade_near: Option<u32>,
-    fade_far: Option<u32>,
+    #[serde(rename = "type")]
+    pub category: Option<String>,
+    pub map_id: Option<u32>,
+    pub guid: Option<String>,
+    pub trail_data: Option<String>,
+    pub texture: Option<String>,
+    pub anim_speed: Option<f32>,
+    pub trail_scale: Option<f32>,
+    pub color: Option<u32>,
+    pub alpha: Option<f32>,
+    pub fade_near: Option<u32>,
+    pub fade_far: Option<u32>,
 }
